class Calc:
    def __init__(self, a=0, b=0):
        self.a = a
        self.b = b
    def add(self):
        return self.a + self.b
    def mul(self):
        return self.a * self.b
    def power(self):
        return self.a ** self.b
    def div(self):
        return self.a / self.b
    def sub(self):
        return self.a - self.b
    def diff_int(self):
        return self.a // self.b
    def mod(self):
        return self.a % self.b
def main():
    a = 2
    b = 4
    calculator = Calc(a, b)
    print(str(a) + '+' + str(b) + ' =', calculator.add())
    print(str(a) + '-' + str(b) + ' =', calculator.sub())
    print(str(a) + '*' + str(b) + ' =', calculator.mul())
    print(str(a) + '/' + str(b) + ' =', calculator.div())
    print(str(a) + '/' + str(b) + ' =', calculator.diff_int())
    print(str(a) + '/' + str(b) + ' =', calculator.mod())
    print(str(a) + '/' + str(b) + ' =', calculator.power())
if __name__ == '__main__':
    main()



import unittest
​
# from calculate import calculate
from program2.calculate import calc
​
​
class TestCalculator(unittest.TestCase):
    '''Testing the calculator2'''
​
    def setUp(self):
        '''Set up testing objects'''
        self.a = 200
        self.b = 100
​
    def test_add(self):
        '''Testing add menthod'''
        calculator = calc.Calc(self.a, self.b)
        print(calculator.add())
        self.assertEqual(calculator.add(), 300)
​
    def test_is_not_add(self):
        '''Testing add menthod'''
        calculator = calc.Calc(self.a, self.b)
        self.assertNotEqual(calculator.add(), 400)
​
    def test_sub(self):
        calculator = calc.Calc(self.a, self.b)
        self.assertEqual(calculator.sub(), 100)
​
    def test_power(self):
        calculator = calc.Calc(self.a, self.b)
        self.assertNotEqual(calculator.power(), 100)
​
    @unittest.skip
    def test_mul(self):
        calculator = calc.Calc(self.a, self.b)
        self.assertEqual(calculator.mul(), 20000)
​
    def test_div(self):
        calculator = calc.Calc(self.a, self.b)
        self.assertEqual(calculator.div(), 2)
​
    def test_mod(self):
        calculator = calc.Calc(self.a, self.b)
        self.assertEqual(calculator.mod(), 0)
​
    def test_diff_int(self):
        calculator = calc.Calc(self.a, self.b)
        self.assertEqual(calculator.diff_int(), 2)
​
​
​
if __name__ == '__main__':
    unittest.main()
​


import setuptools, os

setuptools.setup(
    name="izzyXYZ",  # Replace with your own PyPi
    version=("1.0"),
    author="izzy",
    author_email="izzy@example.com",
    description="A small example package",
    url="https://github.com/naturalett/getting-started",
    install_requires=['distribution-Final', 'boto3'],
    packages=['calculate'],
    scripts=['calculate/calc.py'],
    python_requires='>=3.9',
)